Package: marsrad
Title: Mars Solar Radiation
Version: 1.0.1
Authors@R: 
    person(given = "Georges",
           family = "Labrèche",
           role = c("aut", "cre"),
           email = "georges@tanagraspace.com",
           comment = c(ORCID = "0000-0002-2104-8789"))
Description: A set of functions to calculate solar irradiance and insolation on Mars horizontal and inclined surfaces. Based on NASA Technical Memoranda 102299, 103623, 105216, 106321, and 106700, i.e. the canonical Mars solar radiation papers.
License: GPL-3
URL: https://georges.fyi/marsrad/,
        https://github.com/georgeslabreche/marsrad
BugReports: https://github.com/georgeslabreche/marsrad/issues
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
Depends: R (>= 2.10)
Imports: stats
Suggests: testthat, covr, DT, htmltools
NeedsCompilation: no
Packaged: 2026-05-09 22:44:53 UTC; georgeslabreche
Author: Georges Labrèche [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-2104-8789>)
Maintainer: Georges Labrèche <georges@tanagraspace.com>
Repository: CRAN
Date/Publication: 2026-05-09 23:00:02 UTC
Built: R 4.6.0; ; 2026-05-09 23:23:10 UTC; unix
