# Generated by roxygen2: do not edit by hand

export(G_ali)
export(G_b)
export(G_bh)
export(G_bi)
export(G_dh)
export(G_di)
export(G_h)
export(G_i)
export(G_ob)
export(G_obh)
export(H_ali)
export(H_bh)
export(H_bi)
export(H_dh)
export(H_di)
export(H_h)
export(H_i)
export(H_obh)
export(I_ali)
export(I_bh)
export(I_bi)
export(I_dh)
export(I_di)
export(I_h)
export(I_i)
export(I_obh)
export(T_d)
export(Z)
export(albedo)
export(declination)
export(f)
export(is_irradiated)
export(is_polar_day)
export(is_polar_night)
export(optical_depth)
export(optimal_angle)
export(sunrise)
export(sunset)
importFrom(stats,integrate)
